@@ -143,7 +143,7 @@ void child(char *service, char *username, char *xdisp)
     _exit(BIO_IGNORE);
 }
 
-void handler()
+void handler(int signo)
 {
     return;
 }
